@@ -4,7 +4,7 @@ use warnings;
 use base 'CGI::Application';
 
 use vars qw($VERSION);
-$VERSION = '0.002';
+$VERSION = '0.003';
 
 
 # Load recommended plugins by default. 
@@ -35,7 +35,7 @@ A simple, medium-weight, MVC web framework build on CGI::Application. The framew
 
 The bundled plugins mix the following methods into your controller runmodes:
 
-    $c->forward(runmood)
+    $c->forward(runmode)
 
     $c->redirect(url)
 
@@ -128,21 +128,15 @@ clean url-to-controller mapping by default.
 =back
 
 
-
 Attanium is also different in that it generates a micro-architecture and helper scripts that work within that structure to speed development and maintain project structure. The helper scripts eliminate the tedium of error-prone manual creation of controllers, templates and database mappings.
 
-The skeleton app generated by L<attanium-starter.pl> generates a base class rather than runnable module.  This is 
-differen than the artifacts generated by titanium-starter.pl.  attanium-starter also generates a default 
-'Home' subclass and a CGI::Application::Dispatch instance that is customized to default to the 
-Home subclasses generated 'index' runmode.  
+L<Module::Starter::Plugin::Attanium> comes with the 'attanium-starter.pl' scriptwhich generates a runnable application skeleton.  attanium-starter.pl also generates a default 'Home' controller and a CGI::Application::Dispatch instance that is customized to default to the Home subclasses generated 'index' runmode.  
 
-L<attainum-starter.pl> also generates the script 'YourApp/script/create_controller.pl'  which will 
-generate additional subclasses of your base module with a default 'index' runmode and a 
-default TT template for that runmode. The provided 'YourApp/script/create_dbic_schema.pl' will generate a DBIx::Class::Schema subclass and a set of 
-DBIx::Class::Result set subclasses for your custom databasse.
+attainum-starter.pl also generates a couple helper scripts into your projects roo/scrip directory. The first, 'create_controller.pl', will assist the deveoper by generating controller subclasses of your base module with a default 'index' runmode and a 
+default TT template for that runmode. A 'create_dbic_schema.pl' will also be created in the scripts directory and is used to generate a DBIx::Class::Schema subclass and a set of 
+DBIx::Class::Result set subclasses for your database.
 
-Finally Attanium aims to be as compatible as possible with L<Catalyst> which also has the plugins which were 
-added to Titanium to form Attanium.
+Finally Attanium aims to be as compatible as possible with L<Catalyst> which has plugins for a number of the modules used in Attanium.
 
 
 
@@ -199,7 +193,7 @@ You will need to install L<Attanium> which provides the runtime requirements.  Y
     Created MyApp1/t/perlcriticrc
     Created MyApp1/lib/MyApp1/C                       # YOUR CONTROLLERS GO HERE 
     Created MyApp1/lib/MyApp1/C/Home.pm               # YOUR *DEFAULT CONTROLLER SUBCLASS*
-    Created MyApp1/lib/MyApp1/Dispatch.pm             # YOUR CUSTOM DISPATCHER
+    Created MyApp1/lib/MyApp1/Dispatch.pm             # YOUR CUSTOM URL DISPATCHER
     Created MyApp1/config
     Created MyApp1/config/config-dev.pl               # YOU CONFIG -- MUST BE EDITED BY YOU!
     Created MyApp1/script
